[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - tdl.map.AStar: A* pathfinder
  - tdl.event.App: Application framework.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - tdl.TDLError: The catch all for most TDL specific errors.
  - tdl.event.Event: Base Event class.
    - tdl.event.KeyEvent
      - tdl.event.KeyDown: Fired when the user presses a key on the keyboard or a key repeats.
      - tdl.event.KeyUp: Fired when the user releases a key on the keyboard.
    - tdl.event.MouseButtonEvent
      - tdl.event.MouseDown: Fired when a mouse button is pressed.
      - tdl.event.MouseUp: Fired when a mouse button is released.
    - tdl.event.MouseMotion: Fired when the mouse is moved.
    - tdl.event.Quit: Fired when the window is closed by the user.
  - tdl.noise.Noise: An advanced noise generator.
  - tdl._MetaConsole: Contains methods shared by both the Console and Window classes.
    - tdl.Console: Contains character and color data and can be drawn to.
    - tdl.Window: A Window contains a small isolated part of a Console.